@@ -12,11 +12,11 @@ from raspberry_epaper.get_background_color import get_background_color
 from raspberry_epaper.valid_types import VALID_IMAGE_TYPES, VALID_TEXT_TYPES
 
 
-def build_image(epd, image_filepath):
-    foreImage = Image.open(image_filepath)
-    backColor = get_background_color(foreImage)
-    backImage = Image.new("1", (epd.width(), epd.height()), backColor)
-    image = combine(foreImage, backImage)
+def build_image(epd, image_filepath, **opt):
+    fore_image = Image.open(image_filepath)
+    back_color = get_background_color(fore_image)
+    back_image = Image.new("1", (epd.width(), epd.height()), back_color)
+    image = combine(fore_image, back_image, opt)
     return image
 
 
@@ -44,14 +44,14 @@ def overlay_qr_code(image, qr):
 
 def process(arg):
     logging.debug("Arguments:{}".format(arg))
-    filepath, mimetype = get_filepath_and_mimetype(arg.path)
+    filepath, mimetype = get_filepath_and_mimetype(arg.path, arg.order)
 
     try:
-        epd = EPD(arg.device)
+        epd = EPD(arg.device.value)
         epd.clear()
 
         if mimetype in VALID_IMAGE_TYPES:
-            image = build_image(epd, filepath)
+            image = build_image(epd, filepath, crop=arg.crop)
         elif mimetype in VALID_TEXT_TYPES:
             image = build_text_image(epd, filepath, arg.font, arg.font_size)
 
@@ -63,13 +63,13 @@ def process(arg):
 
     except KeyboardInterrupt:
         logging.info("ctrl + c:")
-        if 'epd' in locals():
+        if "epd" in locals():
             epd.exit()
         sys.exit(1)
 
     except Exception as e:
         logging.error(e)
         logging.error(traceback.format_exc())
-        if 'epd' in locals():
+        if "epd" in locals():
             epd.exit()
         sys.exit(1)
